<?php
$lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails';
$lang['title_detail_returnid'] = 'Page par d&eacute;faut &agrave; utiliser pour des vues de d&eacute;tail';
$lang['title_submission_settings'] = 'Param&egrave;tres de soumission des articles (News)';
$lang['title_fesubmit_settings'] = 'Param&egrave;tres de soumission via le Frontend';
$lang['title_notification_settings'] = 'Param&egrave;tres des notifications';
$lang['title_detail_settings'] = 'Param&eacute;tres d&#039;affichage des d&eacute;tails';
$lang['error_invalidurl'] = 'URL incorrecte <em>(peut-&ecirc;tre d&eacute;j&agrave; utilis&eacute;e, ou il y a des caract&egrave;res non valides)</em>';
$lang['url'] = 'URL ';
$lang['expired_searchable'] = 'Les articles expir&eacute;s peuvent appara&icirc;tre dans les r&eacute;sultats de recherche&nbsp;';
$lang['helpshowall'] = 'Si positionn&eacute; &agrave; 1 : affiche tous les articles, quelle que soit la date de fin';
$lang['error_invaliddates'] = 'Une ou plusieurs dates entr&eacute;es sont invalides';
$lang['notify_n_draft_items_sub'] = '%d article(s)';
$lang['notify_n_draft_items'] = 'Vous avez %s article(s) non publi&eacute;(s)';
$lang['unlimited'] = 'Sans limite';
$lang['none'] = 'Aucun';
$lang['anonymous'] = 'Anonyme';
$lang['unknown'] = 'Inconnu';
$lang['fesubmit_redirect'] = 'PageID ou alias o&ugrave; se fera la redirection apr&egrave;s qu&#039;un article ait &eacute;t&eacute; soumis via l&#039;action fesubmit&nbsp;';
$lang['allow_summary_wysiwyg'] = 'Autoriser l&#039;utilisation de l&#039;&eacute;diteur WYSIWYG dans le sommaire&nbsp;';
$lang['title_browsecat_template'] = 'Gabarit de cat&eacute;gories';
$lang['title_browsecat_sysdefault'] = 'Gabarit de cat&eacute;gories par d&eacute;faut';
$lang['browsecattemplate'] = 'Gabarit de cat&eacute;gories';
$lang['error_filesize'] = 'Un fichier upload&eacute; exc&egrave;de la taille maximum autoris&eacute;e';
$lang['post_date_desc'] = 'Date article post&eacute; descendante';
$lang['post_date_asc'] = 'Date article post&eacute; ascendante';
$lang['expiry_date_desc'] = 'Date expiration descendante';
$lang['expiry_date_asc'] = 'Date expiration ascendante';
$lang['title_desc'] = 'Titre descendant';
$lang['title_asc'] = 'Titre ascendant';
$lang['status_desc'] = 'Status descendant';
$lang['status_asc'] = 'Status ascendant';
$lang['fesubmit_status'] = 'Le statut des articles soumis via les pages du site (frontend)&nbsp;';
$lang['error_invalidfiletype'] = 'Impossible de t&eacute;l&eacute;charger ce type de fichier';
$lang['error_upload'] = 'Il y a eu un probl&egrave;me lors du t&eacute;l&eacute;chargement d&#039;un fichier';
$lang['error_movefile'] = 'Impossible de cr&eacute;er ce fichier : %s';
$lang['error_mkdir'] = 'Impossible de cr&eacute;er ce r&eacute;pertoire : %s';
$lang['expiry_interval'] = 'Le nombre de jours (par d&eacute;faut) avant qu&#039;un article expire (si &quot;Utiliser la date d&#039;expiration&quot; est s&eacute;lectionn&eacute;e)&nbsp;';
$lang['removed'] = 'Supprim&eacute;';
$lang['msg_contenttype_removed'] = 'Le type de contenu News a &eacute;t&eacute; supprim&eacute;. Merci de remplacer les tags {news} avec les param&egrave;tres appropri&eacute;s dans vos gabarits ou vos pages pour remplacer cette fonctionnalit&eacute;.';
$lang['delete_selected'] = 'Supprimer les articles s&eacute;lectionn&eacute;s';
$lang['areyousure_deletemultiple'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer tous ces articles&nbsp;?\nCette action est d&eacute;finitive&nbsp;!';
$lang['error_templatenamexists'] = 'Un gabarit de ce nom existe d&eacute;j&agrave;';
$lang['error_noarticlesselected'] = 'Aucun article s&eacute;lectionn&eacute;';
$lang['reassign_category'] = 'Changer la cat&eacute;gorie par&nbsp;';
$lang['select'] = 'S&eacute;lectionner';
$lang['approve'] = 'Mettre le status &agrave; &#039;Publi&eacute;&#039;';
$lang['revert'] = 'Mettre le status &agrave; &#039;&Eacute;bauche&#039;';
$lang['hide_summary_field'] = 'Cacher le champ sommaire lors de l&#039;ajout ou de la modification d&#039;articles&nbsp;';
$lang['textbox'] = 'Champ de texte';
$lang['checkbox'] = 'Case &agrave; cocher';
$lang['textarea'] = 'Zone de texte';
$lang['file'] = 'Fichier';
$lang['auto_create_thumbnails'] = 'Cr&eacute;ation automatique de fichiers &quot;vignettes&quot; pour les fichiers avec ces extensions';
$lang['allowed_upload_types'] = 'Autoriser seulement le t&eacute;l&eacute;chargement des fichiers avec ces extensions&nbsp;';
$lang['fielddefupdated'] = 'La d&eacute;finition du champ a &eacute;t&eacute; mise &agrave; jour avec succ&egrave;s.';
$lang['editfielddef'] = '&Eacute;diter la d&eacute;finition du champ';
$lang['up'] = 'Haut';
$lang['down'] = 'Bas';
$lang['fielddefdeleted'] = 'La d&eacute;finition du champ a &eacute;t&eacute; supprim&eacute;e avec succ&egrave;s.';
$lang['nameexists'] = 'Un champ de ce nom existe d&eacute;j&agrave;';
$lang['notanumber'] = 'La longueur maximale n&#039;est PAS un nombre';
$lang['fielddef'] = 'D&eacute;finition champ';
$lang['fielddefadded'] = 'La d&eacute;finition du champ a &eacute;t&eacute; ajout&eacute;e avec succ&egrave;s.';
$lang['public'] = 'Publique&nbsp;';
$lang['type'] = 'Type&nbsp;';
$lang['info_maxlength'] = 'Longueur maximale uniquement pour champ de texte.';
$lang['maxlength'] = 'Longueur maximale&nbsp;';
$lang['addfielddef'] = 'Ajouter une d&eacute;finition de champ';
$lang['customfields'] = 'D&eacute;finition des champs';
$lang['deprecated'] = 'Non support&eacute;';
$lang['subject_newnews'] = 'Un nouvel article a &eacute;t&eacute; post&eacute;';
$lang['email_subject'] = 'Le sujet du mail de notification&nbsp;';
$lang['email_template'] = 'Le format du message par email&nbsp;';
$lang['formsubmit_emailaddress'] = 'Adresse email pour recevoir les notifications des articles soumis&nbsp;';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Cat&eacute;gorie t&eacute;l&eacute;chargements';
$lang['title_available_templates'] = 'Gabarits disponibles';
$lang['resettodefault'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
$lang['title_form_template'] = '&Eacute;diteur du gabarit soumission d&#039;article via les pages du site (frontend)';
$lang['title_detail_template'] = '&Eacute;diteur du gabarit du d&eacute;tail';
$lang['title_summary_template'] = '&Eacute;diteur du gabarit du sommaire';
$lang['prompt_templatename'] = 'Nom du gabarit&nbsp;';
$lang['prompt_template'] = 'Source du gabarit&nbsp;';
$lang['title_form_sysdefault'] = 'Gabarit de soumission article par d&eacute;faut (frontend)';
$lang['title_summary_sysdefault'] = 'Gabarit du sommaire par d&eacute;faut';
$lang['title_detail_sysdefault'] = 'Gabarit du d&eacute;tail par d&eacute;faut';
$lang['info_sysdefault2'] = '<strong>Note :</strong> cette page contient des zones d&#039;&eacute;dition des gabarits qui sont disponibles quand vous cr&eacute;ez un &#039;Nouveau&#039; gabarit Sommaire, D&eacute;tail ou Soumission d&#039;article. Le fait de cliquer sur &#039;Envoyer&#039; les donn&eacute;es de cette page <strong>n&#039;aura aucun effet imm&eacute;diat sur l&#039;affichage d&eacute;j&agrave; existant</strong>.';
$lang['info_sysdefault'] = '<em>(le gabarit utilis&eacute; par d&eacute;faut quand un nouveau gabarit est s&eacute;lectionn&eacute;)</em>';
$lang['template'] = 'Gabarit&nbsp;';
$lang['prompt_name'] = 'Nom';
$lang['prompt_default'] = 'D&eacute;faut';
$lang['prompt_newtemplate'] = 'Cr&eacute;er un nouveau gabarit';
$lang['help_pagelimit'] = 'Nombre maximal d&#039;articles affich&eacute;s (par page). Si ce param&egrave;tre n&#039;est pas d&eacute;fini, tous les articles sont affich&eacute;s. Si ce param&egrave;tre est d&eacute;fini, et que le nombre d&#039;articles est sup&eacute;rieur, les textes et les liens seront affich&eacute;s pour permettre le d&eacute;filement des r&eacute;sultats.';
$lang['prompt_page'] = 'Page ';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'sur';
$lang['prompt_pagelimit'] = 'Nombre par page&nbsp;';
$lang['prompt_sorting'] = 'Tri&eacute; par&nbsp;';
$lang['title_filter'] = 'Filtres';
$lang['published'] = 'Publi&eacute;';
$lang['draft'] = '&Eacute;bauche';
$lang['expired'] = 'Expir&eacute;';
$lang['author'] = 'Auteur&nbsp;';
$lang['sysdefaults'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
$lang['restoretodefaultsmsg'] = 'Cette op&eacute;ration restaurera les gabarits par d&eacute;faut. &Ecirc;tes-vous s&ucirc;r(e) de vouloir continuer&nbsp;?';
$lang['addarticle'] = 'Ajouter un article';
$lang['articleadded'] = 'L&#039;article a &eacute;t&eacute; ajout&eacute; avec succ&egrave;s.';
$lang['articleupdated'] = 'L&#039;article a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s.';
$lang['articledeleted'] = 'L&#039;article a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s.';
$lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
$lang['categoryadded'] = 'La cat&eacute;gorie a &eacute;t&eacute; ajout&eacute;e avec succ&egrave;s.';
$lang['categoryupdated'] = 'La cat&eacute;gorie a &eacute;t&eacute; mise &agrave; jour avec succ&egrave;s.';
$lang['categorydeleted'] = 'La cat&eacute;gorie a &eacute;t&eacute; supprim&eacute;e avec succ&egrave;s.';
$lang['addnewsitem'] = 'Ajouter un article';
$lang['allcategories'] = 'Toutes les cat&eacute;gories';
$lang['allentries'] = 'Toutes les entr&eacute;es';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer&nbsp;?';
$lang['articles'] = 'Articles ';
$lang['cancel'] = 'Annuler';
$lang['category'] = 'Cat&eacute;gorie&nbsp;';
$lang['categories'] = 'Cat&eacute;gories';
$lang['default_category'] = 'Cat&eacute;gorie par d&eacute;faut&nbsp;';
$lang['content'] = 'Contenu&nbsp;';
$lang['dateformat'] = '%s pas dans un format valide yyyy-mm-dd hh:mm:ss';
$lang['delete'] = 'Effacer';
$lang['description'] = 'Ajout, &eacute;dition et suppression des articles';
$lang['formtemplate'] = 'Gabarit soumission article';
$lang['detailtemplate'] = 'Gabarit du d&eacute;tail article';
$lang['default_templates'] = 'Gabarits par d&eacute;faut';
$lang['detailtemplateupdated'] = 'Le gabarit de l&#039;affichage du d&eacute;tail de l&#039;article a &eacute;t&eacute; sauvegard&eacute; dans la base de donn&eacute;es.';
$lang['displaytemplate'] = 'Afficher le gabarit';
$lang['edit'] = '&Eacute;diter';
$lang['enddate'] = 'Date de fin&nbsp;';
$lang['endrequiresstart'] = 'Entrer une date de fin n&eacute;cessite qu&#039;une date de d&eacute;but soit &eacute;galement entr&eacute;e';
$lang['entries'] = '%s entr&eacute;es';
$lang['status'] = 'Statut';
$lang['expiry'] = 'Expiration';
$lang['filter'] = 'Filtre';
$lang['more'] = 'Plus';
$lang['category_label'] = 'Cat&eacute;gorie&nbsp;:';
$lang['author_label'] = 'Post&eacute; par&nbsp;:';
$lang['moretext'] = 'Texte pour ';
$lang['name'] = 'Nom&nbsp;';
$lang['news'] = 'Articles';
$lang['news_return'] = 'Retour';
$lang['newcategory'] = 'Nouvelle cat&eacute;gorie';
$lang['needpermission'] = 'Vous devez avoir la permission &#039;%s&#039; pour ex&eacute;cuter cette action.';
$lang['nocategorygiven'] = 'Aucune cat&eacute;gorie entr&eacute;e';
$lang['startdatetoolate'] = 'la date de d&eacute;but est pass&eacute;e (apr&egrave;s la date de fin ?)';
$lang['nocontentgiven'] = 'Aucun contenu entr&eacute;';
$lang['noitemsfound'] = '<strong>Aucun</strong> objet trouv&eacute; pour cette cat&eacute;gorie: %s';
$lang['nopostdategiven'] = 'Il manque la date &agrave; laquelle l&#039;article sera post&eacute;';
$lang['note'] = '<em>Note :</em> les dates doivent &ecirc;tre entr&eacute;es dans ce format &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Aucun titre n&#039;est entr&eacute;';
$lang['nonamegiven'] = 'Aucun nom n&#039;a &eacute;t&eacute; donn&eacute;';
$lang['numbertodisplay'] = 'Nombre &agrave; afficher (vide = toutes les entr&eacute;es)&nbsp;';
$lang['print'] = 'Imprimer';
$lang['postdate'] = 'Date &agrave; laquelle l&#039;article sera post&eacute;&nbsp;';
$lang['postinstall'] = 'Assurez-vous que les utilisateurs qui administreront les articles aient la permission &quot;Modify News&quot;.';
$lang['selectcategory'] = 'S&eacute;lection de cat&eacute;gorie';
$lang['showchildcategories'] = 'Afficher les sous-cat&eacute;gories&nbsp;';
$lang['sortascending'] = 'Tri ascendant&nbsp;';
$lang['startdate'] = 'Date de d&eacute;but&nbsp;';
$lang['startoffset'] = 'Commence l&#039;affichage au &eacute;ni&egrave;me article&nbsp;';
$lang['startrequiresend'] = 'Entrer une date de d&eacute;but n&eacute;cessite qu&#039;une date de fin soit &eacute;galement entr&eacute;e';
$lang['submit'] = 'Envoyer';
$lang['summary'] = 'Sommaire&nbsp;';
$lang['summarytemplate'] = 'Gabarit du sommaire article';
$lang['summarytemplateupdated'] = 'Le gabarit de l&#039;affichage du sommaire de l&#039;article a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s';
$lang['title'] = 'Titre&nbsp;';
$lang['options'] = 'Options ';
$lang['optionsupdated'] = 'Les options ont &eacute;t&eacute; mises &agrave; jour avec succ&egrave;s';
$lang['useexpiration'] = 'Utiliser la date d&#039;expiration&nbsp;';
$lang['eventdesc-NewsArticleAdded'] = 'Envoy&eacute; quand un article est ajout&eacute;';
$lang['eventhelp-NewsArticleAdded'] = '<p>Envoy&eacute; quand un article est ajout&eacute;</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;news_id&quot; - Id de l&#039;article</li>
<li>&quot;category_id&quot; - Id de la cat&eacute;gorie de cet article</li>
<li>&quot;title&quot; - Titre de l&#039;article</li>
<li>&quot;content&quot; - Contenu de l&#039;article</li>
<li>&quot;summary&quot; - Sommaire de l&#039;article</li>
<li>&quot;status&quot; - Statut de l&#039;article (&quot;draft&quot; or &quot;published&quot;)</li>
<li>&quot;start_time&quot; - Date de d&eacute;but de publication de l&#039;article</li>
<li>&quot;end_time&quot; - Date de fin de publication de l&#039;article</li>
<li>&quot;useexp&quot; - Si la date d&#039;expiration doit &ecirc;tre ignor&eacute;e ou pas</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Envoy&eacute; quand un article est &eacute;dit&eacute;';
$lang['eventhelp-NewsArticleEdited'] = '<p>Envoy&eacute; quand un article est &eacute;dit&eacute;</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;news_id&quot; - Id de l&#039;article</li>
<li>&quot;category_id&quot; - Id de la cat&eacute;gorie de cet article</li>
<li>&quot;title&quot; - Titre de l&#039;article</li>
<li>&quot;content&quot; - Contenu de l&#039;article</li>
<li>&quot;summary&quot; - Sommaire de l&#039;article</li>
<li>&quot;status&quot; - Statut de l&#039;article (&quot;draft&quot; or &quot;published&quot;)</li>
<li>&quot;start_time&quot; - Date de d&eacute;but de publication de l&#039;article</li>
<li>&quot;end_time&quot; - Date de fin de publication de l&#039;article</li>
<li>&quot;useexp&quot; - Si la date d&#039;expiration doit &ecirc;tre ignor&eacute;e ou pas</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Envoy&eacute; quand un article est supprim&eacute;';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Envoy&eacute; quand un article est supprim&eacute;</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;news_id&quot; - Id de l&#039;article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Envoy&eacute; quand une cat&eacute;gorie est ajout&eacute;e';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est ajout&eacute;e</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
<li>&quot;name&quot; - Nom de la cat&eacute;gorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Envoy&eacute; quand une cat&eacute;gorie est &eacute;dit&eacute;e';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est &eacute;dit&eacute;e</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
<li>&quot;name&quot; - Nom de la cat&eacute;gorie</li>
<li>&quot;origname&quot; - Nom original de la cat&eacute;gorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Envoy&eacute; quand une cat&eacute;gorie est supprim&eacute;e';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est supprim&eacute;e</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
<li>&quot;name&quot; - Nom de la cat&eacute;gorie supprim&eacute;e</li>
</ul>
';
$lang['help_articleid'] = 'Ce param&egrave;tre est applicable uniquement &agrave; la vue de d&eacute;tail. Il permet de sp&eacute;cifier que l&#039;article sera afficher en mode d&eacute;tail. Si la valeur utilis&eacute;e est -1, le syst&egrave;me affichera l&#039;article le plus r&eacute;cemment, publi&eacute;, mais non expir&eacute;.';
$lang['helpnumber'] = 'Le nombre maximal d&#039;articles &agrave; afficher -- laisser ce param&egrave;tre vide affichera tous les articles. C&#039;est identique au param&egrave;tre &quot;pagelimit&quot;.';
$lang['helpstart'] = 'Commence au &eacute;ni&egrave;me article -- laisser ce param&egrave;tre vide commencera l&#039;affichage au premier article';
$lang['helpcategory'] = 'Affiche les articles de cette cat&eacute;gorie seulement. Utiliser * pour afficher les sous-cat&eacute;gories. Des cat&eacute;gories multiples peuvent &ecirc;tre affich&eacute;es en les s&eacute;parant par une virgule. Laisser ce param&egrave;tre vide affichera tous les articles.';
$lang['helpmoretext'] = 'Texte &agrave; afficher &agrave; la fin d&#039;un article qui d&eacute;passe la longueur d&eacute;finie du sommaire. Par d&eacute;faut = &quot;Plus&quot;';
$lang['helpsummarytemplate'] = 'Utilise la base de donn&eacute;e pour afficher le formulaire de soumission du sommaire des articles. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit du sommaire article&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
$lang['helpformtemplate'] = 'Utilise la base de donn&eacute;e pour afficher le formulaire de soumission de l&#039;article. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit soumission article&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
$lang['helpbrowsecattemplate'] = 'Utilise la base de donn&eacute;e pour afficher les gabarits de cat&eacute;gories. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit de cat&eacute;gories&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
$lang['helpdetailtemplate'] = 'Utilise la base de donn&eacute;e pour afficher le formulaire de soumission du d&eacute;tail des articles.  Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit du d&eacute;tail article&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
$lang['helpsortby'] = 'Champ sur lequel trier les articles.  Les options sont : &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;,  &quot;end_time&quot;, &quot;start_time&quot;,  &quot;random&quot;.  Par d&eacute;faut: &quot;news_date&quot;.  Si &quot;random&quot; est sp&eacute;cifi&eacute;, le crit&egrave;re de tri est ignor&eacute;.';
$lang['helpsortasc'] = 'Trie les articles dans un ordre de date ascendant plut&ocirc;t que descendant. Par d&eacute;faut: descendant.';
$lang['helpdetailpage'] = 'Page dans laquelle afficher le d&eacute;tail des articles. Vous pouvez entrer soit un alias, soit un ID de page. Utile pour permettre d&#039;afficher le d&eacute;tail de l&#039;article dans un gabarit de page diff&eacute;rent de celui du sommaire.';
$lang['helpshowarchive'] = 'Afficher seulement les articles expir&eacute;s.';
$lang['helpbrowsecat'] = 'Afficher une liste navigable de cat&eacute;gories';
$lang['helpaction'] = 'Outrepasse l&#039;action par d&eacute;faut. Les valeurs possibles sont :
<ul>
<li>&quot;detail&quot; - pour afficher l&#039;article en mode d&eacute;tail.</li>
<li>&quot;default&quot; - pour afficher le sommaire de l&#039;article</li>
<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site.</li>
<li>&quot;browsecat&quot; - pour afficher une liste de cat&eacute;gories.</li>
</ul>

';
$lang['help'] = '<h3>Notes Importantes</h3>
<p>la Version 2.9 a supprim&eacute; le format &quot;formatpostdate&quot; des gabarits, et a &eacute;galement supprim&eacute; le param&egrave;tre &quot;dateformat&quot;. Vous devez utiliser le param&egrave;tre &quot;cms_date_format&quot; (comme indiqu&eacute; dans les gabarits par d&eacute;faut) pour les format des dates, et devrait utiliser entry->postdate au lieu de entry->formatpostdate dans vos gabarits.</p>
<h3>Que fait ce module ?</h3>
	<p>Articles (News en anglais) est un module qui sert &agrave; afficher des articles sur vos pages, de fa&ccedil;on similaire &agrave; un blog, mais avec plus de fonctions ! D&egrave;s que le module est install&eacute;, une page de gestion des articles est ajout&eacute;e au menu d&#039;administration qui vous permettra de s&eacute;lectionner ou ajouter des cat&eacute;gories d&#039;articles. D&egrave;s qu&#039;une cat&eacute;gorie d&#039;article est s&eacute;lectionn&eacute;e ou cr&eacute;&eacute;e, une liste des articles pour cette cat&eacute;gorie est affich&eacute;e. Depuis l&agrave;, vous pouvez ajouter, &eacute;diter ou supprimer les articles dans cette cat&eacute;gorie.</p>
<h4>Champs personnalis&eacute;s</h4>
<p>Le module permet de d&eacute;finir de nombreux champs personnalis&eacute;s (y compris les fichiers et images) qui vous permettront de joindre des fichiers PDF ou de nombreuses images &agrave; vos articles.</p>
            <h4>Cat&eacute;gories</h4>
	<p>Le module News (Articles) fournit un m&eacute;canisme de cat&eacute;gories hi&eacute;rarchiques de l&#039;organisation de vos articles. Un article ne peut &ecirc;tre qu&#039;en un seul endroit dans la hi&eacute;rarchie</p>
	<h4>Expiration et le statut</h4>
	<p>Chaque article peut avoir une option de date d&#039;expiration, qui n&#039;affichera plus l&#039;article sur votre page Web. En outre, les articles peuvent &ecirc;tre marqu&eacute;s comme <em>brouillon</em> pour les supprimer d&eacute;finitivement de l&#039;affichage votre page Web</p>
	<h3>S&eacute;curit&eacute;</h3>
	<p>L&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Modify News&#039; pour pouvoir ajouter, &eacute;diter ou supprimer des articles.</p>
<p>Pour supprimer les articles, l&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Delete News Articles&#039;..</p>
	<p>Pour modifier la pr&eacute;sentation des gabarits, l&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &quot;Modify Templates&quot;</p>
	<p>Pour modifier les pr&eacute;f&eacute;rences globales du module, l&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Modify Site Preferences&#039;.</p>
	<p>En plus, pour approuver les articles soumis par un visiteur sur la page du site (frontend) l&#039;utilisateur doit appartenir &agrave; un groupe avec la permission  &#039;Approve News&#039; .</p>
	<h3>Comment l&#039;utiliser&nbsp;?</h3>
	<p>La fa&ccedil;on la plus facile de l&#039;utiliser est avec la balise wrapper {news} (englobe le module dans une simple balise pour simplifier la syntaxe).  Cela ins&egrave;rera votre module dans votre gabarit ou votre page &agrave; l&#039;endroit d&eacute;sir&eacute;, et y affichera les articles.  Exemple de syntaxe : <code>{news number=&#039;5&#039;}</code></p>
<h3>Gabarits</h3>
	<p>Depuis la version 2.3 le module News peut utiliser diff&eacute;rentes bases de donn&eacute;es, et donc n&#039;utilise plus les fichiers de &quot;templates&quot;. Les utilisateurs qui avaient des anciens fichiers gabarits doivent faire les modifications suivantes (pour chaque fichier gabarits) :</p>
<ul>
<li>Copier le fichier dans le presse papier</li>
<li>Cr&eacute;er un nouveau gabarit <em>(sommaire ou d&eacute;tail suivant le besoin)</em>. Donner le m&ecirc;me nom au gabarit que l&#039;ancien nom du gabarits (y compris l&#039;extension .tpl), et coller le contenu depuis le presse papier.</li>
<li>Cliquer sur le bouton Envoyer</li>
</ul>
<p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
$lang['qca'] = 'P0-1532147203-1273233257739';
$lang['utma'] = '156861353.1552570550.1277739492.1284456886.1284478759.4';
$lang['utmz'] = '156861353.1284138366.2.2.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>